@@ -41,8 +41,8 @@ class SEWIRF(ModelBase):
             "rho2": 0.167, "rho3": 0.167,
         },
         "y0_dict": {
-            "Susceptible": 994_000, "Exposed": 3000, "Waiting": 0.002,
-            "Infected": 1000, "Recovered": 0, "Fatal": 0,
+            ModelBase.S: 994_000, ModelBase.E: 3000, ModelBase.W: 0.002,
+            ModelBase.CI: 1000, ModelBase.R: 0, ModelBase.F: 0,
         },
     }
 
