@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import pytest
+import warnings
 from covsirphy import ChangeFinder
 from covsirphy import PhaseSeries
 
@@ -13,9 +14,19 @@ class TestChangeFinder(object):
     )
     def test_find(self, jhu_data, population_data, country):
         population = population_data.value(country)
-        clean_df = jhu_data.subset(country, population=population)
         change_finder = ChangeFinder(
-            clean_df, population, country=country
+            jhu_data, population, country=country
+        )
+        change_finder.run()
+        phase_series = change_finder.show()
+        assert isinstance(phase_series, PhaseSeries)
+
+    def test_find_with_dataframe(self, jhu_data, population_data):
+        population = population_data.value("Italy")
+        clean_df = jhu_data.cleaned()
+        warnings.filterwarnings("ignore", category=DeprecationWarning)
+        change_finder = ChangeFinder(
+            clean_df, population, country="Italy"
         )
         change_finder.run()
         phase_series = change_finder.show()
